"""
Tests of the Event class
"""

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from neo.core.event import Event

class TestEvent(unittest.TestCase):
    pass


if __name__ == "__main__":
    unittest.main()
